==> ejc-jltest-impl-3.0.0-20240323.031742-97-sources.jar: com/ejianc/business/jltest/margin/bean/DirectEmployeeDetailEntity.java <==
package com.ejianc.business.jltest.margin.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 直管部缴纳员工明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_direct_employee_detail")
public class DirectEmployeeDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="direct_employee_id")
    private Long directEmployeeId; // 标准表ID
    @TableField(value="direct_employee_code")
    private String directEmployeeCode; //直管部人员表编码

    @TableField(value="employee_id")
    private Long employeeId; // 人员id
    @TableField(value="role_name")
    private String roleName;
    @TableField(value="employee_name")
    private String employeeName; // 人员名称
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="wage_mny")
    private BigDecimal wageMny; // 工资金额
    @TableField(value="margin_mny")
    private BigDecimal marginMny; // 缴纳金额
    @TableField(value="margin_ratio")
    private BigDecimal marginRatio; // 缴纳占比
    @TableField(value="margin_actual")
    private BigDecimal marginActual; // 实际缴纳金额
    @TableField(value="margin_unpaid")
    private BigDecimal marginUnpaid; // 未缴纳金额
    @TableField(value="by_stages")
    private Integer byStages; // 是否分期（1-是 2-否）
    @TableField(value="argin_unpaid_ratio")
    private BigDecimal arginUnpaidRatio; // 实际缴纳占比
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getDirectEmployeeId() {
        return directEmployeeId;
    }

    public void setDirectEmployeeId(Long directEmployeeId) {
        this.directEmployeeId = directEmployeeId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getWageMny() {
        return wageMny;
    }

    public void setWageMny(BigDecimal wageMny) {
        this.wageMny = wageMny;
    }
    public BigDecimal getMarginMny() {
        return marginMny;
    }

    public void setMarginMny(BigDecimal marginMny) {
        this.marginMny = marginMny;
    }
    public BigDecimal getMarginRatio() {
        return marginRatio;
    }

    public void setMarginRatio(BigDecimal marginRatio) {
        this.marginRatio = marginRatio;
    }
    public BigDecimal getMarginActual() {
        return marginActual;
    }

    public void setMarginActual(BigDecimal marginActual) {
        this.marginActual = marginActual;
    }
    public BigDecimal getMarginUnpaid() {
        return marginUnpaid;
    }

    public void setMarginUnpaid(BigDecimal marginUnpaid) {
        this.marginUnpaid = marginUnpaid;
    }
    public Integer getByStages() {
        return byStages;
    }

    public void setByStages(Integer byStages) {
        this.byStages = byStages;
    }
    public BigDecimal getArginUnpaidRatio() {
        return arginUnpaidRatio;
    }

    public void setArginUnpaidRatio(BigDecimal arginUnpaidRatio) {
        this.arginUnpaidRatio = arginUnpaidRatio;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getDirectEmployeeCode() {
        return directEmployeeCode;
    }

    public void setDirectEmployeeCode(String directEmployeeCode) {
        this.directEmployeeCode = directEmployeeCode;
    }

    public String getRoleName() {
        return roleName;
    }

    public void setRoleName(String roleName) {
        this.roleName = roleName;
    }
}

==> ejc-jltest-impl-3.0.0-20240328.003309-121-sources.jar: com/ejianc/business/jltest/margin/bean/DirectEmployeeDetailEntity.java <==
package com.ejianc.business.jltest.margin.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 直管部缴纳员工明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_direct_employee_detail")
public class DirectEmployeeDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="direct_employee_id")
    private Long directEmployeeId; // 主表ID
    @TableField(value="direct_employee_code")
    private String directEmployeeCode; //直管部人员表编码
    @TableField(value="org_id")
    private Long orgId; //申请组织Id
    @TableField(value="org_name")
    private String orgName; //申请组织名称
    @TableField(value="employee_id")
    private Long employeeId; // 人员id
    @TableField(value="role_name")
    private String roleName;
    @TableField(value="employee_name")
    private String employeeName; // 人员名称
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="wage_mny")
    private BigDecimal wageMny; // 工资金额
    @TableField(value="margin_mny")
    private BigDecimal marginMny; // 缴纳金额
    @TableField(value="margin_ratio")
    private BigDecimal marginRatio; // 缴纳占比
    @TableField(value="margin_actual")
    private BigDecimal marginActual; // 实际缴纳金额
    @TableField(value="margin_unpaid")
    private BigDecimal marginUnpaid; // 未缴纳金额
    @TableField(value="accumulated_mny")
    private BigDecimal accumulatedMny; // 未缴纳金额
    @TableField(value="has_record")
    private Integer hasRecord; //是否存在记录 1-否 2-是
    @TableField(value="by_stages")
    private Integer byStages; // 是否分期（1-是 2-否）
    @TableField(value="argin_unpaid_ratio")
    private BigDecimal arginUnpaidRatio; // 实际缴纳占比
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getDirectEmployeeId() {
        return directEmployeeId;
    }

    public void setDirectEmployeeId(Long directEmployeeId) {
        this.directEmployeeId = directEmployeeId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getWageMny() {
        return wageMny;
    }

    public void setWageMny(BigDecimal wageMny) {
        this.wageMny = wageMny;
    }
    public BigDecimal getMarginMny() {
        return marginMny;
    }

    public void setMarginMny(BigDecimal marginMny) {
        this.marginMny = marginMny;
    }
    public BigDecimal getMarginRatio() {
        return marginRatio;
    }

    public void setMarginRatio(BigDecimal marginRatio) {
        this.marginRatio = marginRatio;
    }
    public BigDecimal getMarginActual() {
        return marginActual;
    }

    public void setMarginActual(BigDecimal marginActual) {
        this.marginActual = marginActual;
    }
    public BigDecimal getMarginUnpaid() {
        return marginUnpaid;
    }

    public void setMarginUnpaid(BigDecimal marginUnpaid) {
        this.marginUnpaid = marginUnpaid;
    }
    public Integer getByStages() {
        return byStages;
    }

    public void setByStages(Integer byStages) {
        this.byStages = byStages;
    }
    public BigDecimal getArginUnpaidRatio() {
        return arginUnpaidRatio;
    }

    public void setArginUnpaidRatio(BigDecimal arginUnpaidRatio) {
        this.arginUnpaidRatio = arginUnpaidRatio;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getDirectEmployeeCode() {
        return directEmployeeCode;
    }

    public void setDirectEmployeeCode(String directEmployeeCode) {
        this.directEmployeeCode = directEmployeeCode;
    }

    public String getRoleName() {
        return roleName;
    }

    public void setRoleName(String roleName) {
        this.roleName = roleName;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public BigDecimal getAccumulatedMny() {
        return accumulatedMny;
    }

    public void setAccumulatedMny(BigDecimal accumulatedMny) {
        this.accumulatedMny = accumulatedMny;
    }

    public Integer getHasRecord() {
        return hasRecord;
    }

    public void setHasRecord(Integer hasRecord) {
        this.hasRecord = hasRecord;
    }
}
